==> portal-service-6.0.6-sources.jar: com/liferay/portal/kernel/util/Constants.java <==
/**
 * Copyright (c) 2000-2011 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.kernel.util;

/**
 * @author Brian Wing Shun Chan
 */
public interface Constants {

	public static final String ACTION = "action";

	public static final String ADD = "add";

	public static final String APPROVE = "approve";

	public static final String ASSIGN = "assign";

	public static final String CANCEL = "cancel";

	public static final String CHECKOUT = "checkout";

	public static final String CMD = "cmd";

	public static final String COPY = "copy";

	public static final String DEACTIVATE = "deactivate";

	public static final String DELETE = "delete";

	public static final String EDIT = "edit";

	public static final String EXPIRE = "expire";

	public static final String LOCK = "lock";

	public static final String MAIL_ACCOUNT = "mail_account";

	public static final String MANAGE = "manage";

	public static final String MOVE = "move";

	public static final String PREVIEW = "preview";

	public static final String PRINT = "print";

	public static final String PROGRESS_ID = "progressId";

	public static final String PUBLISH = "publish";

	public static final String REJECT = "reject";

	public static final String READ = "read";

	public static final String RESET = "reset";

	public static final String RESTORE = "restore";

	public static final String REVERT = "revert";

	public static final String SAVE = "save";

	public static final String SEARCH = "search";

	public static final String SEND = "send";

	public static final String SIGNAL = "signal";

	public static final String SUBSCRIBE = "subscribe";

	public static final String UNLOCK = "unlock";

	public static final String UNSUBSCRIBE = "unsubscribe";

	public static final String UPDATE = "update";

	public static final String VIEW = "view";

	public static final String WRITE = "write";

}

==> portal-service-6.1.0-sources.jar: com/liferay/portal/kernel/util/Constants.java <==
/**
 * Copyright (c) 2000-2012 Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.portal.kernel.util;

/**
 * @author Brian Wing Shun Chan
 */
public interface Constants {

	public static final String ACTION = "action";

	public static final String ADD = "add";

	public static final String ADD_TEMP = "add_temp";

	public static final String ADD_MULTIPLE = "add_multiple";

	public static final String APPROVE = "approve";

	public static final String ASSIGN = "assign";

	public static final String CANCEL = "cancel";

	public static final String CANCEL_CHECKOUT = "cancel_checkout";

	public static final String CHECKIN = "checkin";

	public static final String CHECKOUT = "checkout";

	public static final String CMD = "cmd";

	public static final String COPY = "copy";

	public static final String DEACTIVATE = "deactivate";

	public static final String DELETE = "delete";

	public static final String DELETE_TEMP = "delete_temp";

	public static final String DELETE_TRANSLATION = "delete_translation";

	public static final String DELETE_VERSIONS = "delete_versions";

	public static final String EDIT = "edit";

	public static final String EXPIRE = "expire";

	public static final String EXPORT = "export";

	public static final String GET_TEMP = "get_temp";

	public static final String IMPORT = "import";

	public static final String LOCK = "lock";

	public static final String MAIL_ACCOUNT = "mail_account";

	public static final String MANAGE = "manage";

	public static final String MERGE = "merge";

	public static final String MOVE = "move";

	public static final String PREVIEW = "preview";

	public static final String PRINT = "print";

	public static final String PROGRESS_ID = "progressId";

	public static final String PUBLISH = "publish";

	public static final String REJECT = "reject";

	public static final String READ = "read";

	public static final String RESET = "reset";

	public static final String RESTORE = "restore";

	public static final String REVERT = "revert";

	public static final String SAVE = "save";

	public static final String SEARCH = "search";

	public static final String SEND = "send";

	public static final String SIGNAL = "signal";

	public static final String SUBSCRIBE = "subscribe";

	public static final String SUBSCRIBE_TO_COMMENTS = "subscribe_to_comments";

	public static final String TEST = "test";

	public static final String TRANSLATE = "translate";

	public static final String UNLOCK = "unlock";

	public static final String UNSUBSCRIBE = "unsubscribe";

	public static final String UNSUBSCRIBE_FROM_COMMENTS =
		"unsubscribe_from_comments";

	public static final String UPDATE = "update";

	public static final String UPDATE_AND_CHECKIN = "update_and_checkin";

	public static final String VIEW = "view";

	public static final String VOTE = "vote";

	public static final String WRITE = "write";

}
